==> bun-skin-1.1.1.tgz: package/skin/middleware/Render.js <==
'use strict';

const resolve = require('path').resolve;
// const nunjucks = require('nunjucks');
const pug = require('pug');
const fs = require('fs');

/**
 * See: http://mozilla.github.io/nunjucks/api.html#configure
 * @param  {[type]} path nunjucks configure path
 * @param  {[type]} opts nunjucks configure opts
 * @return {[type]}      [description]
 */
module.exports = (path, opts) => {
    path = resolve(path || 'views');
    opts = opts || {};
    const ext = '.' + (opts.ext || 'html');
    // if (opts.ext !== 'html') {
    //     const renderTool = require(opts.ext);
    // } else {
    //     const env = nunjucks.configure(path, opts);

    //     const filters = opts.filters || {};
    //     const globals = opts.globals || {};

    //     Object.keys(filters).forEach(k => {
    //         env.addFilter(k, filters[k]);
    //     });
    //     Object.keys(globals).forEach(k => {
    //         env.addGlobal(k, globals[k]);
    //     });
    // }
    
    return function view(ctx, next) {
        if (ctx.render) return next();

        const render = pug.renderFile;
        // 渲染模板出html
        ctx.renderHtml = async (view, locals) => {
            const appname = view.split('/')[1]
            const manifest = await fs.readFile(bun.ROOT_PATH + 'static/'+ appname +'/manifest.json')
            const state = Object.assign({}, ctx.state, locals, {staticSources: JSON.parse(manifest.toString())})

            return new Promise((res, rej) => {
                render(path +'/'+ view + ext, state, (err, html) => {
                    if (err) return rej(err);
                    
                    res(html);
                });
            });
        };
        // 渲染模板并渲染到页面
        ctx.render = (view, locals) => {
            const appname = view.split('/')[1]
            const manifest = await fs.readFile(bun.ROOT_PATH + 'static/'+ appname +'/manifest.json')
            const state = Object.assign({}, ctx.state, locals, {staticSources: JSON.parse(manifest.toString())})

            return new Promise((res, rej) => {
                render(path +'/'+view + ext, state, (err, html) => {
                    if (err) return rej(err);
                    // Render with response content-type, fallback to text/html
                    ctx.type = ctx.type || 'text/html';
                    ctx.body = html;
                    res();
                });
            });
        };
        return next();
    };
};

==> bun-skin-1.2.0.tgz: package/skin/middleware/Render.js <==
'use strict';

const resolve = require('path').resolve;
// const nunjucks = require('nunjucks');
const pug = require('pug');
const fs = require('fs');

/**
 * See: http://mozilla.github.io/nunjucks/api.html#configure
 * @param  {[type]} path nunjucks configure path
 * @param  {[type]} opts nunjucks configure opts
 * @return {[type]}      [description]
 */
module.exports = (path, opts) => {
    path = resolve(path || 'views');
    opts = opts || {};
    const ext = '.' + (opts.ext || 'html');
    // if (opts.ext !== 'html') {
    //     const renderTool = require(opts.ext);
    // } else {
    //     const env = nunjucks.configure(path, opts);

    //     const filters = opts.filters || {};
    //     const globals = opts.globals || {};

    //     Object.keys(filters).forEach(k => {
    //         env.addFilter(k, filters[k]);
    //     });
    //     Object.keys(globals).forEach(k => {
    //         env.addGlobal(k, globals[k]);
    //     });
    // }
    
    return function view(ctx, next) {
        if (ctx.render) return next();

        const render = pug.renderFile;
        // 渲染模板出html
        ctx.renderHtml = async (view, locals) => {
            const appname = view.split('/')[1]
            const manifest = await fs.readFile(bun.ROOT_PATH + 'static/'+ appname +'/manifest.json')
            const state = Object.assign({}, ctx.state, locals, {staticSources: JSON.parse(manifest.toString())})

            return new Promise((res, rej) => {
                render(path +'/'+ view + ext, state, (err, html) => {
                    if (err) return rej(err);
                    
                    res(html);
                });
            });
        };
        // 渲染模板并渲染到页面
        ctx.render = async (view, locals) => {
            const appname = view.split('/')[1]
            const manifest = await fs.readFile(bun.ROOT_PATH + 'static/'+ appname +'/manifest.json')
            const state = Object.assign({}, ctx.state, locals, {staticSources: JSON.parse(manifest.toString())})

            return new Promise((res, rej) => {
                render(path +'/'+view + ext, state, (err, html) => {
                    if (err) return rej(err);
                    // Render with response content-type, fallback to text/html
                    ctx.type = ctx.type || 'text/html';
                    ctx.body = html;
                    res();
                });
            });
        };
        return next();
    };
};
